nextPaymentAmountMoney property
Read only The current amount due for the invoice. In addition to the amount due on the next payment request, this includes any overdue payment amounts.
Implementation
final Money? nextPaymentAmountMoney;
Read only The current amount due for the invoice. In addition to the amount due on the next payment request, this includes any overdue payment amounts.
final Money? nextPaymentAmountMoney;