paymentRequests property
The payment schedule for the invoice, represented by one or more payment requests that define payment settings, such as amount due and due date. An invoice supports the following payment request combinations:
- One balance
- One deposit with one balance
- 2-12 installments
- One deposit with 2-12 installments
This field is required when creating an invoice. It must contain at least one payment request. All payment requests for the invoice must equal the total order amount. For more information, see Configuring payment requests.
Adding INSTALLMENT payment requests to an invoice requires an
Invoices Plus subscription.
Implementation
final List<InvoicePaymentRequest>? paymentRequests;